@@ -16,7 +16,7 @@ has missing_after => 1800;
 has remove_after  => 172800;
 has tasks         => sub { {} };
 
-our $VERSION = '7.03';
+our $VERSION = '7.04';
 
 sub add_task { ($_[0]->tasks->{$_[1]} = $_[2]) and return $_[0] }
 
@@ -27,6 +27,21 @@ sub enqueue {
   return $id;
 }
 
+sub foreground {
+  my ($self, $id) = @_;
+
+  return undef unless my $job = $self->job($id);
+  return undef
+    unless $job->retry({attempts => 1, queue => 'minion_foreground'});
+
+  my $worker = $self->worker->register;
+  $job = $worker->dequeue(0 => {id => $id, queues => ['minion_foreground']});
+  $job->_run and $job->finish if $job;
+  $worker->unregister;
+
+  return !!$job;
+}
+
 sub job {
   my ($self, $id) = @_;
 
@@ -394,6 +409,13 @@ Queue to put job in, defaults to C<default>.
 
 =back
 
+=head2 foreground
+
+  my $bool = $minion->foreground($id);
+
+Retry job in C<minion_foreground> queue, then perform it right away with a
+temporary worker in this process, very useful for debugging.
+
 =head2 job
 
   my $job = $minion->job($id);
