@@ -55,19 +55,27 @@ sub start {
   return $self->emit(spawn => $pid) if $self->{pid} = $pid;
 
   # Child
-  eval {
+  $self->_run;
+  POSIX::_exit(0);
+}
+
+sub stop { kill 'KILL', shift->{pid} }
+
+sub _run {
+  my $self = shift;
+
+  return 1 if eval {
 
     # Reset event loop
     Mojo::IOLoop->reset;
     $self->minion->tasks->{$self->emit('start')->task}->($self, @{$self->args});
 
     1;
-  } or $self->fail($@);
-  POSIX::_exit(0);
+  };
+  $self->fail($@);
+  return undef;
 }
 
-sub stop { kill 'KILL', shift->{pid} }
-
 1;
 
 =encoding utf8
@@ -397,6 +405,12 @@ These options are currently available:
 
 =over 2
 
+=item attempts
+
+  attempts => 25
+
+Number of times performing this job will be attempted.
+
 =item delay
 
   delay => 10
